/**
 * a class which implements a simple counter
 *
 * @version	$Id: Counter.java,v 1.2 2003/02/19 15:16:39 nthiery Exp $
 * @author	Nicolas M. Thiry <nthiery@users.sourceforge.net>
**/

class Counter {
    int i;
    
    /**
     * Constructor for a counter initialized at zero
     *
     * @param	
     **/
    public Counter() {
	i=0;
    }

    /**
     * Increase the counter by one
     *
     * @param	
     * @return
     **/
    public void increase() {
	i=i+1;
    }

    /**
     * Returns the current value of the counter
     *
     * @param	
     * @return	a nonnegative integer: the value of the counter
     **/
    public int get() {
	return(i);
    }
}
